import { aws_ec2 as ec2, aws_ecs as ecs, aws_elasticloadbalancingv2 as elbv2, aws_iam as iam } from "aws-cdk-lib";
import { Construct } from "constructs";
/**
 * Configuration for ECS service autoscaling.
 */
export interface AutoScalingProps {
    /** Minimum number of tasks */
    readonly minCapacity: number;
    /** Maximum number of tasks */
    readonly maxCapacity: number;
    /** Target CPU utilization percentage */
    readonly targetCpuUtilizationPercent: number;
    /** Cooldown time in seconds after scale-in */
    readonly scaleInCooldownSec?: number;
    /** Cooldown time in seconds after scale-out */
    readonly scaleOutCooldownSec?: number;
}
export interface EcsCodeDeployProps {
    readonly vpc: ec2.IVpc;
    readonly cluster: ecs.ICluster;
    readonly containerPort: number;
    readonly serviceName: string;
    readonly imageUri: string;
    readonly certificateArn: string;
    readonly environment: string;
    readonly enablePublicLoadBalancer?: boolean;
    readonly autoScaling?: AutoScalingProps;
    readonly healthCheck?: ecs.HealthCheck;
}
export declare class EcsCodeDeploy extends Construct {
    readonly service: ecs.FargateService;
    readonly loadBalancer: elbv2.ApplicationLoadBalancer;
    taskRole: iam.Role;
    constructor(scope: Construct, id: string, props: EcsCodeDeployProps);
}
